using System;
using System.Collections.Generic;
using System.Globalization;
using System.Windows.Data;
using System.Windows.Media;

namespace RenderableSeriesViewModel.Converters
{
    public class ColorToBrushConverter : IValueConverter
    {
        // Dictionary to cache brushes.
        private readonly Dictionary<Color, SolidColorBrush> _brushCache = new();

        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is Color color)
            {
                // Check if the brush for this color is already cached.
                if (!_brushCache.TryGetValue(color, out var brush))
                {
                    brush = new SolidColorBrush(color);
                    brush.Freeze(); // Freezing to enhance performance.
                    _brushCache[color] = brush;
                }
                return brush;
            }

            // Return transparent brush if the value isn't a Color.
            return Brushes.Transparent;
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is SolidColorBrush brush)
            {
                return brush.Color;
            }

            // Return Colors.Transparent if the value isn't a SolidColorBrush.
            return Colors.Transparent;
        }
    }
}