﻿using RenderableSeriesViewModel.ViewModels;
using SciChart.Charting.ChartModifiers;
using SciChart.Charting.Model.ChartSeries;
using SciChart.Charting.Visuals;
using SciChart.Core.Extensions;
using SciChart.Core.Utility.Mouse;
using SciChart.Data.Model;
using System;
using System.Collections.ObjectModel;
using System.Linq;

namespace RenderableSeriesViewModel.CustomModifiers
{
    internal class CustomZoomExtentsModifier : ChartModifierBase
    {
        public override void OnModifierDoubleClick(ModifierMouseArgs e)
        {
            base.OnModifierDoubleClick(e);

            ParentSurface.ZoomExtentsToVisibleRangeLimit(MainViewModel.RangeYAxis);
        }
    }

    public static class SciChartSurfaceExtensions
    {
        public static void ZoomExtentsToVisibleRangeLimit(this ISciChartSurface scs, ObservableCollection<NumericAxisViewModel> yAxes)
        {
            using (scs.SuspendUpdates())
            {

                foreach (var axis in scs.YAxes)
                {
                    var rangeX = (from s in yAxes
                                  where s.Id == axis.Id
                                  select s.VisibleRange.Min).Single().ToDouble();

                    var rangeY = (from s in yAxes
                                  where s.Id == axis.Id
                                  select s.VisibleRange.Max).Single().ToDouble();

                    IRange range = new DoubleRange(rangeX, rangeY);

                    axis.AnimateVisibleRangeTo(range, TimeSpan.FromMilliseconds(50));
                }

                foreach (var axis in scs.XAxes)
                {
                    var range = axis.VisibleRangeLimit ?? axis.GetMaximumRange();
                    axis.AnimateVisibleRangeTo(range, TimeSpan.FromMilliseconds(2000));
                }
            }
        }
    }
}
